<?php

namespace Drupal\drupal_moodle_integration\Services;

/**
 * Class UserService.
 */
class UserService {

  /**
   * Check if Moodle connection is configured.
   */
  public function isConfigured() {
    $config = \Drupal::config('drupal_moodle_integration.settings');
    return $config->get('url') && $config->get('wstoken');
  }

  /**
   * Function to get Create users In moodle.
   */
  public function moodleCreateUser($users) {
    $config = \Drupal::config('drupal_moodle_integration.settings');
    $baseurl = $config->get('url') . '/webservice/rest/server.php?';
    $params = [
      'wstoken' => $config->get('wstoken'),
      'wsfunction' => 'core_user_create_users',
      'moodlewsrestformat' => 'json',
      'users' => $users,
    ];
    $url = $baseurl . http_build_query($params);
    $response = file_get_contents($url);
    $newusers = json_decode($response);
    return $newusers[0]->id;
  }

  /**
   * Function to update users in moodle.
   */
  public function moodleUpdateUser($users) {
    $config = \Drupal::config('drupal_moodle_integration.settings');
    $baseurl = $config->get('url') . '/webservice/rest/server.php?';
    $params = [
      'wstoken' => $config->get('wstoken'),
      'wsfunction' => 'core_user_update_users',
      'moodlewsrestformat' => 'json',
      'users' => $users,
    ];
    $url = $baseurl . http_build_query($params);
    $response = file_get_contents($url);
    json_decode($response);
  }

  /**
   * Get users.
   */
  public static function getUsers() {
    $config = \Drupal::config('drupal_moodle_integration.settings');
    $baseurl = $config->get('url') . '/webservice/rest/server.php?';
    $params = [
      'wstoken' => $config->get('wstoken'),
      'wsfunction' => 'core_user_get_users',
      'moodlewsrestformat' => 'json',
      'criteria' => [
        ['key' => 'email', 'value' => '%%'],
      ],
    ];
    $url = $baseurl . http_build_query($params);
    $response = file_get_contents($url);
    $users = json_decode($response);
    return $users;
  }

}
